/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.sample.common.internal

import android.content.Context
import android.os.Bundle
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentActivity
import androidx.viewpager2.adapter.FragmentStateAdapter
import com.kakao.sdk.common.KakaoSdk
import com.kakao.sdk.partner.model.KakaoPhase
import com.kakao.sdk.partner.sample.common.PartnerFragment
import com.kakao.sdk.partner.sample.common.PartnerFragmentRx
import com.kakao.sdk.sample.common.OpenFragment
import com.kakao.sdk.sample.common.OpenFragmentRx

class TabAdapter(context: Context, fa: FragmentActivity) : FragmentStateAdapter(fa) {
    private val bundle: Bundle = when (KakaoPhase.fromName(
        context.getSharedPreferences(
            "default",
            Context.MODE_PRIVATE
        ).getString("phase", KakaoPhase.PRODUCTION.phaseName) as String
    )) {
        KakaoPhase.DEV, KakaoPhase.OMEGA -> Bundle().apply {
            putLong("customMemo", 151202)
            putLong("customMessage", 151202)
            putString("channelId", "_xnrxjem")
            putString("calendarEventId", "639964bc7edd5d0c9b722c14")
        }

        KakaoPhase.SANDBOX -> Bundle().apply {
            putLong("customMemo", 682)
            putLong("customMessage", 682)
            putString("channelId", "_KQu")
            putString("calendarEventId", "63917cbbca3adc72adfff94a")
            putString("settleId", "ee82f111-12f3-4a96-9bcf-8ff0e1f56cde")
        }

        KakaoPhase.CBT -> Bundle().apply {
            putLong("customMemo", 19383)
            putLong("customMessage", 19383)
            putString("channelId", "_ZeUTxl")
            putString("calendarEventId", "63996425afcec577cce94f0b")
            putString("settleId", "12713dac-e9ab-4107-83b2-9edce225e65a ")
        }

        KakaoPhase.PRODUCTION -> Bundle().apply {
            putLong("customMemo", 19383)
            putLong("customMessage", 19383)
            putString("channelId", "_ZeUTxl")
            putString("calendarEventId", "63996425afcec577cce94f0b")
            putString("settleId", "f3318663-771a-4b24-8714-3f3061fa17cd")
        }
    }

    val fragments = if (KakaoSdk.type == KakaoSdk.Type.KOTLIN) {
        listOf(
            HostFragment.newInstance(OpenFragment.newInstance(bundle), "Open"),
            HostFragment.newInstance(PartnerFragment.newInstance(bundle), "Partner")
        )
    } else {
        listOf(
            HostFragment.newInstance(OpenFragmentRx.newInstance(bundle), "Open"),
            HostFragment.newInstance(PartnerFragmentRx.newInstance(bundle), "Partner")
        )
    }

    override fun getItemCount(): Int = fragments.size

    override fun createFragment(position: Int): Fragment = fragments[position]
}
